Column and Data Types — SQLAlchemy 1.2 Documentation

Release: 1.2.5 | Release Date: March 6, 2018

# SQLAlchemy 1.2 Documentation

# Column and Data Types

- Column and Data Types
  - Generic Types
  - SQL Standard and Multiple Vendor Types
  - Vendor-Specific Types
- Custom Types
  - Overriding Type Compilation
  - Augmenting Existing Types
  - TypeDecorator Recipes
  - Replacing the Bind/Result Processing of Existing Types
  - Applying SQL-level Bind/Result Processing
  - Redefining and Creating New Operators
  - Creating New Types
- Base Type API